Summary: An embeddable LISP environment.
Name: librep
Version: 0.12.4
Release: 7
Copyright: GPL
Group: Development/Languages
Source: http://download.sourceforge.net/librep/librep-%{version}.tar.gz
Prefix: %{_prefix}
Patch0: librep-%{version}-aixlt.patch
URL: http://librep.sourceforge.net/
Buildroot: /var/tmp/%{name}-%{version}-%{release}-root
BuildRequires: libtool >= 1.3.5
Prereq: /sbin/install-info

%ifarch ia64
  %define stdlib lib/ia64l32
  %define stdlib64 lib/ia64l64
  %define liblink ../../..
  %define PKG64 %{name}-%{version}-ia64l64
  %define DIRS . %{_builddir}/%{PKG64}/%{name}-%{version}
  %define DEFCCIA cc
  %define DEFCC %{DEFCCIA}
%else
  %define stdlib lib
  %define liblink ../..
  %define DIRS .
  # Have to patch some things to work with vac
  %define DEFCC gcc
%endif

%description
Librep is a dialect of LISP for use embedded in other applications or
on its own. Librep is mostly (but not fully) compatible with Emacs
LISP. Librep contains a LISP interpreter, a byte-code compiler and a
virtual machine. Applications can use the LISP interpreter as an
extension language, or it can be used for standalone scripts.

%package devel
Summary: Include files and link libraries for librep development.
Group: Development/Languages
Requires: librep = %{version}

%description devel
The link libraries and C header files for librep development. Librep
is an embeddable dialect of LISP.

%prep
%setup -q
%patch0 -p1 -b .aixlt

%build
# Use the default compiler for this platform - gcc otherwise
if [[ -z "$CC" ]]
then
    if test "X`type %{DEFCC} 2>/dev/null`" != 'X'; then
       export CC=%{DEFCC}
    else 
       export CC=gcc
    fi
fi
if test "X$CC" != "Xgcc"
then
       export RPM_OPT_FLAGS=`echo $RPM_OPT_FLAGS | sed 's:-fsigned-char::'`
       export CFLAGS="$RPM_OPT_FLAGS"
fi

libtoolize --force
%ifarch ppc rs6000
export LDFLAGS="-Wl,-brtl"
%else
export LDFLAGS=""
%endif
LDFLAGS="$LDFLAGS" CFLAGS="$RPM_OPT_FLAGS" ./configure --with-readline --prefix=%{_prefix} %{_host}
make CFLAGS="$RPM_OPT_FLAGS" LDFLAGS="$LDFLAGS"

%install
rm -rf $RPM_BUILD_ROOT
make install \
    prefix=$RPM_BUILD_ROOT%{_prefix} \
    aclocaldir=$RPM_BUILD_ROOT%{_prefix}/share/aclocal
gzip -9nf $RPM_BUILD_ROOT%{_prefix}/info/librep*

#find $RPM_BUILD_ROOT -type f -name "*.so*" -exec strip --strip-unneeded {} \;

strip $RPM_BUILD_ROOT%{prefix}/bin/* || :

( cd $RPM_BUILD_ROOT
 for dir in bin include
 do
    mkdir -p usr/$dir
    cd usr/$dir
    ln -sf ../..%{prefix}/$dir/* .
    cd -
 done

 mkdir -p usr/%{stdlib}
 cd usr/%{stdlib}
 ln -sf %{liblink}%{prefix}/lib/* .
)

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root)
%doc NEWS README TODO
%{_prefix}/bin/rep
%{_prefix}/bin/rep-remote
%{_prefix}/lib/librep.so*
/usr/bin/rep
/usr/bin/rep-remote
/usr/%{stdlib}/librep.so*
%{_prefix}/share/rep/%{version}/lisp/*.jl
%{_prefix}/share/rep/%{version}/lisp/*.jlc
%{_prefix}/libexec/rep/%{version}/*/*.so*
%{_prefix}/libexec/rep/%{version}/*/*.la
%{_prefix}/libexec/rep/%{version}/*/DOC
%{_prefix}/info/librep*

%files devel
%defattr(-,root,root)
%{_prefix}/bin/rep-config
%{_prefix}/bin/repdoc
%{_prefix}/include/rep.h
%{_prefix}/include/rep_*.h
/usr/bin/rep-config
/usr/bin/repdoc
/usr/include/rep.h
/usr/include/rep_*.h
%attr(755,root,root) %{_prefix}/libexec/rep/*/libtool
%{_prefix}/libexec/rep/*/rules.mk
%{_prefix}/share/aclocal/rep.m4

%post
#/sbin/ldconfig
/sbin/install-info %{_prefix}/info/librep.info.gz %{_prefix}/info/dir

%preun 
if [ $1 = 0 ]; then
	/sbin/install-info --delete %{_prefix}/info/librep.info.gz %{_prefix}/info/dir
fi

%changelog
* Wed Apr 18 2001 David Clissold <cliss@austin.ibm.com>
- Binaries weren't being stripped

* Fri Mar 09 2001 Marc Stephenson <marc@austin.ibm.com>
- Add logic for default compiler
- Rebuild against new shared objects

* Fri Feb 16 2001 aixtoolbox <aixtoollbox-l@austin.ibm.com>
- Account for different standard lib location in IA64 32-bit ABI

* Fri Oct 27 2000 pkgmgr <pkgmgr@austin.ibm.com>
- Modify for AIX Freeware distribution

* Thu Feb  3 2000 Bill Nottingham <notting@redhat.com>
- add install-info stuff

* Mon Jan 10 2000 Bill Nottingham <notting@redhat.com>
- update to 0.10
- don't pacakge ldconfig symlinks

* Thu Nov 11 1999 Michael K. Johnson <johnsonm@redhat.com>
- Remove stack tracing on alpha in order not to trigger internal
  compiler error.  Should be reverted when we get a newer
  compiler; development gcc has this fixed.

* Wed Nov 10 1999 Michael K. Johnson <johnsonm@redhat.com>
- post{,un} use -p

* Mon Sep 13 1999 Aron Griffis <agriffis@bigfoot.com>
- 0.5 spec file update: added buildroot
